<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="lo">
<context>
    <name>AddonsPage</name>
    <message>
        <location filename="../qml/AddonsPage.qml" line="20"/>
        <source>Add-ons</source>
        <translation>ສ່ວນເຕີມ</translation>
    </message>
</context>
<context>
    <name>AdvancedSettingsModule</name>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="15"/>
        <source>Advanced Settings</source>
        <translation>ການຕັ້ງຄ່າຂັ້ນສູງ</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="41"/>
        <source>&quot;Advanced Settings&quot; is only valid for the input method that uses the system settings, if the input method has its own settings, its own settings shall prevail.</source>
        <translation>&quot;ການຕັ້ງຄ່າຂັ້ນສູງ&quot; ໃຊ້ງານໄດ້ສຳລັບວິທີປ້ອນຂໍ້ມູນທີ່ໃຊ້ການຕັ້ງຄ່າລະບົບເທົ່ານັ້ນ, ຖ້າວິທີປ້ອນຂໍ້ມູນມີການຕັ້ງຄ່າຂອງຕົນເອງ, ການຕັ້ງຄ່າຂອງຕົນເອງຈະຖືກນຳໃຊ້ເປັນຫຼັກ.</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="54"/>
        <source>Global Config</source>
        <translation>ການຕັ້ງຄ່າທົ່ວໄປ</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="70"/>
        <source>Add-ons</source>
        <translation>ສ່ວນເຕີມ</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="81"/>
        <source>Keyboard layout</source>
        <translation>ການຈັດການປ້ອນຂໍ້ມູນບາຍການ</translation>
    </message>
</context>
<context>
    <name>DetailConfigItem</name>
    <message>
        <location filename="../qml/DetailConfigItem.qml" line="151"/>
        <source>Please enter a new shortcut</source>
        <translation>ກະລຸນາປ້ອນສັງລວມທີ່ໃຫມ່</translation>
    </message>
</context>
<context>
    <name>IMList</name>
    <message>
        <location filename="../qml/IMList.qml" line="152"/>
        <source>Move Up</source>
        <translation>ເຄື່ອນໄຫວຂຶ້ນ</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="160"/>
        <source>Move Down</source>
        <translation>ເຄື່ອນໄຫວລົງ</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="168"/>
        <source>Settings</source>
        <translation>ການຕັ້ງຄ່າ</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="176"/>
        <source>Remove</source>
        <translation>ລຶບ</translation>
    </message>
</context>
<context>
    <name>InputMethodsChooser</name>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="35"/>
        <source>Add input method</source>
        <translation>ເພີ່ມວິທີການປ້ອນຂໍ້ມູນ</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="41"/>
        <source>Search</source>
        <translation>ຄົ້ນຫາ</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="109"/>
        <source>Find more in App Store</source>
        <translation>ຄົ້ນຫາມາກຂຶ້ນໃນໂຮງຂາງການຊື້ຂາຍ</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="129"/>
        <source>Cancel</source>
        <translation>ຢກເລີກ</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="136"/>
        <source>Add</source>
        <translation>ເພີ່ມ</translation>
    </message>
</context>
<context>
    <name>KeyboardLayout</name>
    <message>
        <location filename="../qml/KeyboardLayout.qml" line="16"/>
        <source>Keyboard layout</source>
        <translation>ການຈັດວາງແປ້ນພິມ</translation>
    </message>
    <message>
        <location filename="../qml/KeyboardLayout.qml" line="34"/>
        <source>done</source>
        <translation>ສຳເລັດ</translation>
    </message>
    <message>
        <location filename="../qml/KeyboardLayout.qml" line="34"/>
        <source>edit</source>
        <translation>ແກ້ໄຂ</translation>
    </message>
    <message>
        <location filename="../qml/KeyboardLayout.qml" line="57"/>
        <source>Add the corresponding input method in &lt;a style=&apos;text-decoration: none;&apos; href=&apos;Manage Input Methods&apos;&gt;Input Method Management&lt;/a&gt; to ensure the keyboard layout works when added or switched.</source>
        <translation>ເພີ່ມວິທີການປ້ອນຂໍ້ມູນທີ່ສະແດງຢູ່ໃນ &lt;a style=&apos;text-decoration: none;&apos; href=&apos;Manage Input Methods&apos;&gt;Input Method Management&lt;/a&gt; ເພື່ອຄວບຄຸມການປ້ອນຂໍ້ມູນບາຍການເມື່ອເພີ່ມ ຫຼື ສະແດງຢູ່.</translation>
    </message>
    <message>
        <location filename="../qml/KeyboardLayout.qml" line="142"/>
        <source>Add new keyboard layout...</source>
        <translation>ເພີ່ມການຈັດການປ້ອນຂໍ້ມູນບາຍການໃຫມ່...</translation>
    </message>
</context>
<context>
    <name>KeyboardLayoutModule</name>
    <message>
        <location filename="../qml/KeyboardLayoutModule.qml" line="16"/>
        <source>Keyboard layout</source>
        <translation>ການຈັດການປ້ອນຂໍ້ມູນບາຍການ</translation>
    </message>
    <message>
        <location filename="../qml/KeyboardLayoutModule.qml" line="34"/>
        <source>done</source>
        <translation>ສຳເລັດ</translation>
    </message>
    <message>
        <location filename="../qml/KeyboardLayoutModule.qml" line="34"/>
        <source>edit</source>
        <translation>ແກ້ໄຂ</translation>
    </message>
    <message>
        <location filename="../qml/KeyboardLayoutModule.qml" line="57"/>
        <source>Add the corresponding input method in &lt;a style=&apos;text-decoration: none;&apos; href=&apos;Manage Input Methods&apos;&gt;Input Method Management&lt;/a&gt; to ensure the keyboard layout works when added or switched.</source>
        <translation>ເພີ່ມວິທີການປ້ອນຂໍ້ມູນທີ່ສະແດງຢູ່ໃນ &lt;a style=&apos;text-decoration: none;&apos; href=&apos;Manage Input Methods&apos;&gt;Input Method Management&lt;/a&gt; ເພື່ອຄວບຄຸມການປ້ອນຂໍ້ມູນບາຍການເມື່ອເພີ່ມ ຫຼື ສະແດງຢູ່.</translation>
    </message>
    <message>
        <location filename="../qml/KeyboardLayoutModule.qml" line="140"/>
        <source>Add new keyboard layout...</source>
        <translation>ເພີ່ມການຈັດການປ້ອນຂໍ້ມູນບາຍການໃຫມ່...</translation>
    </message>
</context>
<context>
    <name>LayoutsChooser</name>
    <message>
        <location filename="../qml/LayoutsChooser.qml" line="30"/>
        <source>Add new keyboard layout</source>
        <translation>ເພີ່ມການຈັດການປ້ອນຂໍ້ມູນບາຍການໃຫມ່</translation>
    </message>
    <message>
        <location filename="../qml/LayoutsChooser.qml" line="38"/>
        <source>Search</source>
        <translation>ຄົ້ນຫາ</translation>
    </message>
    <message>
        <location filename="../qml/LayoutsChooser.qml" line="67"/>
        <source>Current language keyboard layouts</source>
        <translation>ການຈັດການປ້ອນຂໍ້ມູນບາຍການຂອງພາສາປັດໄສ</translation>
    </message>
    <message>
        <location filename="../qml/LayoutsChooser.qml" line="90"/>
        <source>Cancel</source>
            <translation>ຢກເລີກ</translation>
    </message>
    <message>
        <location filename="../qml/LayoutsChooser.qml" line="97"/>
        <source>Add</source>
        <translation>ເພີ່ມ</translation>
    </message>
</context>
<context>
    <name>ManageInputMethodsModule</name>
    <message>
        <location filename="../qml/ManageInputMethodsModule.qml" line="15"/>
        <source>Input method management</source>
        <translation>ການຈັດການວິທີການປ້ອນຂໍ້ມູນ</translation>
    </message>
    <message>
        <location filename="../qml/ManageInputMethodsModule.qml" line="33"/>
        <source>Add input method</source>
        <translation>ເພີ່ມວິທີການປ້ອນຂໍ້ມູນ</translation>
    </message>
</context>
<context>
    <name>ShortcutsModule</name>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="12"/>
        <location filename="../qml/ShortcutsModule.qml" line="14"/>
        <location filename="../qml/ShortcutsModule.qml" line="151"/>
        <location filename="../qml/ShortcutsModule.qml" line="152"/>
        <source>None</source>
        <translation>ບໍ່ມີ</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="119"/>
        <source>Shortcuts</source>
        <translation>ສັງລວມ</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="134"/>
        <source>Restore Defaults</source>
        <translation>ກັ່ນຕອງຄ່າເລີ່ມຕົ້ນ</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="200"/>
        <source>Scroll between input methods</source>
        <translation>ເຄື່ອນໄຫວລະຫວ່າງວິທີການປ້ອນຂໍ້ມູນ</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="230"/>
        <source>Turn on or off input methods</source>
        <translation>ເປີດ ຫຼື ອອກວິທີການປ້ອນຂໍ້ມູນ</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="273"/>
        <source>It turns on or off the currently used input method.If no input method is being used or the first input method is not the keyboard, it switches between the first input method and the currently used keyboard/input method.</source>
        <translation>ມັນຈະເປີດ ຫຼື ປິດວິທີການປ້ອນຂໍ້ມູນທີ່ກຳລັງໃຊ້ຢູ່. ຖ້າບໍ່ມີວິທີການປ້ອນຂໍ້ມູນຖືກໃຊ້ ຫຼື ວິທີການປ້ອນຂໍ້ມູນອັນດັບທຳອິດບໍ່ແມ່ນແປ້ນພິມ, ມັນຈະສະຫຼັບລະຫວ່າງວິທີການປ້ອນຂໍ້ມູນອັນດັບທຳອິດ ແລະ ແປ້ນພິມ/ວິທີການປ້ອນຂໍ້ມູນທີ່ກຳລັງໃຊ້ຢູ່.</translation>
    </message>
</context>
<context>
    <name>dcc::Locale::dialectNames</name>
    <message>
        <location filename="../keyboard-layout/operation/dcclocale.cpp" line="62"/>
        <source>Traditional Chinese (Chinese Hong Kong)</source>
        <translation>ພາສາຈີນທີ່ດັ່ງການ (ຈີນຮອງໂກໂລນ)</translation>
    </message>
    <message>
        <location filename="../keyboard-layout/operation/dcclocale.cpp" line="65"/>
        <source>Traditional Chinese (Chinese Taiwan)</source>
        <translation>ພາສາຈີນທີ່ດັ່ງການ (ຈີນທາວານ)</translation>
    </message>
</context>
<context>
    <name>dcc::Locale::regionNames</name>
    <message>
        <location filename="../keyboard-layout/operation/dcclocale.cpp" line="86"/>
        <source>Taiwan China</source>
        <translation>ຈີນທາວານ</translation>
    </message>
</context>
<context>
    <name>dccV25::KeyboardController</name>
    <message>
        <location filename="../keyboard-layout/operation/keyboardcontroller.cpp" line="55"/>
        <source>This shortcut conflicts with [%1]</source>
            <translation>ປຸ່ມລັດນີ້ຂັດແຍ້ງກັບ [%1]</translation>
    </message>
</context>
<context>
    <name>dccV25::ShortcutModel</name>
    <message>
        <location filename="../keyboard-layout/operation/shortcutmodel.cpp" line="248"/>
        <source>System</source>
        <translation>ລະບົບ</translation>
    </message>
    <message>
        <location filename="../keyboard-layout/operation/shortcutmodel.cpp" line="253"/>
        <source>Window</source>
        <translation>ໜ້າຕ່າງ</translation>
    </message>
    <message>
        <location filename="../keyboard-layout/operation/shortcutmodel.cpp" line="258"/>
        <source>Workspace</source>
        <translation>ພື້ນທີ່ເຮັດວຽກ</translation>
    </message>
    <message>
        <location filename="../keyboard-layout/operation/shortcutmodel.cpp" line="263"/>
        <source>AssistiveTools</source>
        <translation>ເຄື່ອງມືຊ່ວຍເຫຼືອ</translation>
    </message>
    <message>
        <location filename="../keyboard-layout/operation/shortcutmodel.cpp" line="268"/>
        <location filename="../keyboard-layout/operation/shortcutmodel.cpp" line="339"/>
        <source>Custom</source>
        <translation>ກຳນົດເອງ</translation>
    </message>
    <message>
        <location filename="../keyboard-layout/operation/shortcutmodel.cpp" line="394"/>
        <source>None</source>
        <translation>ບໍ່ມີ</translation>
    </message>
</context>
<context>
    <name>fcitx5configtool</name>
    <message>
        <location filename="../qml/fcitx5configtool.qml" line="8"/>
        <source>Input Methods</source>
        <translation>ວິທີການປ້ອນຂໍ້ມູນ</translation>
    </message>
    <message>
        <location filename="../qml/fcitx5configtool.qml" line="9"/>
        <source>Input method management, input method shortcuts, advanced settings</source>
        <translation>ການຈັດການວິທີການປ້ອນຂໍ້ມູນ, ວິທີການປ້ອນຂໍ້ມູນເວົ້າສັ້ນ, ວາລະສານຂັ້ນສູງ</translation>
    </message>
</context>
</TS>